;-----------------------------------------------------------------------------
; JU+TE TINY  ES1988 / ES2.0
; Include-Datei mit Systemfunktionen, V. Pohlers 01/2022
;------------------------------------------------------------------------------


; Prozeduren aus ES2.0

TBS		EQU	0824h		; Tastenabfrage statisch mit Ausfhrung auf Bildschirm, Kursor (%5B) wird aktualisiert, %5A := ASCII
ZBS		EQU	0827h		; Darstellen eines ASCII aus %5A auf dem Bildschirm, Kursor (%5B) wird aktualisiert
ZBS4		EQU	0872h		; Darstellen eines ASCII aus %5A auf dem Bildschirm, Kursor (%5B) wird aktualisiert. Steuerzeichen werden nicht erkannt
INK		EQU	0875h		; Erhhen des Kursors (%5B) um 1 mit ggf. Bildrollen
EDK		EQU	0878h		; Erhhen des Kursors (%5B) um den Inhalt von %5C mit ggf. Bildrollen
CLS		EQU	08DDh		; Bild lschen, Kursor (%5B) := 0
PrtDezNr1	EQU	0AA3h		; Dezimalausgabe aus %12 und %13 ohne fhrende Nullen RP = #%10
NLE		EQU	0ACEh		; Zeilenschaltung  (new line) ohne Freizeilensperre
NLN		EQU	0AD4h		; Zeilenschaltung mit Freizeilensperre
PrtChar		EQU	0B95h		; Darstellen eines ASCII aus %5A auf dem Bildschirm, Kursor bleibt unverndert, Steuerzeichen werden nicht erkannt
TSK		EQU	0C1Dh		; Tastenabfrage statisch ohne Ausfhrung auf dem Bildschirm %5A:= ASCII
TAS		EQU	0C56h		; Tastenabfrage dynamisch mittels Tastencoderegister (%6D): T-Bit und ASCII
PrtList		EQU	0DCCh		; Anzeige einer BASIC-Zeile ohne Zeilennummer ab Adresse aus %10 und %11, die Adresse wird aktualisiert RP = #%10 %6E = #%0C %6F = #%E6
PrtDezNr	EQU	0E92h		; Dezimalanzeige aus %12 und %13 ohne fhrende Nullen mit Zeilenschaltung RP = #%10


; Prozeduren aus ES1988

ES_Begin	EQU 	2000h		; Routinen im zweiten EPROM des EMR-ES
ES_Load		EQU 	27DFh
ES_Save		EQU 	26ADh

; Systemzellen

CURSOR		EQU	05Bh		; Bit7=0, Bit6..4 = Zeilennummer 0..7, Bit 3..0 = Spaltennummer 0..12
TAST		EQU	06Dh		; Bit7=T-Bit, Bit6..0 = ASCII

; Speicher

GBWS		EQU	0FE00h		; FE00-FFFF 512 Byte Graphik-Bildwiederholspeicher
STACKU		EQU	0FDFFh		; FD80-FDFF 128 Byte Systemstack
STACKL		EQU	0FD80h		; FD80-FDFF 128 Byte Systemstack
BWS		EQU	0FD00h		; FD00-FD7F 128 Byte ASCII-Bildwiederholspeicher
EXTM		EQU	0FC80h		; FC80-FCFF 128 Byte frei fr Standard-Programme
DMA		EQU	0FC00h		; FC00-FC7F 128 Byte Magnetbandpuffer

; Steuerzeichen

C_OFF:		EQU	7Fh		; "OFF"		; allg. lschen
C_RIGHT:	EQU	1Bh		; "Cursor rechts"
C_UP:		EQU	1Ah		; "Cursor hoch"
C_DOWN:		EQU	0Ah		; "Cursor runter"
C_LEFT:		EQU	0Bh		; "Cursor links"
C_BS:		EQU	8		; "CLR"		; Backspace
C_ENTER:	EQU	0Dh		; "ENTER"
C_CLS:		EQU	0Ch		; "CLS"

;------------------------------------------------------------------------------

; BASIC-Variablen

var_A_hi 	equ 	20h
var_A_lo 	equ 	21h
var_B_hi 	equ 	22h
var_B_lo 	equ 	23h
var_C_hi 	equ 	24h
var_C_lo 	equ 	25h
var_D_hi 	equ 	26h
var_D_lo 	equ 	27h
var_E_hi 	equ 	28h
var_E_lo 	equ 	29h
var_F_hi 	equ 	2Ah
var_F_lo 	equ 	2Bh
var_G_hi 	equ 	2Ch
var_G_lo 	equ 	2Dh
var_H_hi 	equ 	2Eh
var_H_lo 	equ 	2Fh
var_I_hi 	equ 	30h
var_I_lo 	equ 	31h
var_J_hi 	equ 	32h
var_J_lo 	equ 	33h
var_K_hi 	equ 	34h
var_K_lo 	equ 	35h
var_L_hi 	equ 	36h
var_L_lo 	equ 	37h
var_M_hi 	equ 	38h
var_M_lo 	equ 	39h
var_N_hi 	equ 	3Ah
var_N_lo 	equ 	3Bh
var_O_hi 	equ 	3Ch
var_O_lo 	equ 	3Dh
var_P_hi 	equ 	3Eh
var_P_lo 	equ 	3Fh
var_Q_hi 	equ 	40h
var_Q_lo 	equ 	41h
var_R_hi 	equ 	42h
var_R_lo 	equ 	43h
var_S_hi 	equ 	44h
var_S_lo 	equ 	45h
var_T_hi 	equ 	46h
var_T_lo 	equ 	47h
var_U_hi 	equ 	48h
var_U_lo 	equ 	49h
var_V_hi 	equ 	4Ah
var_V_lo 	equ 	4Bh
var_W_hi 	equ 	4Ch
var_W_lo 	equ 	4Dh
var_X_hi 	equ 	4Eh
var_X_lo 	equ 	4Fh
var_Y_hi 	equ 	50h
var_Y_lo 	equ 	51h
var_Z_hi 	equ 	52h
var_Z_lo 	equ 	53h

;------------------------------------------------------------------------------
; Z8-Register

P0		EQU	00H		; Port 0
P1		EQU	01H		; Port 1
P2		EQU	02H		; Port 2
P3		EQU	03H		; Port 3
SIO		EQU	0F0H		; serielles Ein-Ausgaberegister
FLAGS		EQU	0FCH		; Flagregister
SPH		EQU	0FEH		; Stackpointer, Highteil
SPL		EQU	0FFH		; Stackpointer, Lowteil
TMR		EQU	0F1H		; Zhler/Zeitgeberbetriebsart
T0		EQU	0F4H		; Zhler/Zeitgeberregister Kanal 0
T1		EQU	0F2H		; Zhler/Zeitgeberregister Kanal 1
PRE0		EQU	0F5H		; T0-Vorteilerregister
PRE1		EQU	0F3H		; T1-Vorteilerregister
P01M		EQU	0F8H		; Tor 0, Tor 1 Betriebsart
P2M		EQU	0F6H		; Tor 2 Betriebsart
P3M		EQU	0F7H		; Tor 3 Betriebsart
IMR		EQU	0FBH		; Interrupt-Maskierungsregister
IPR		EQU	0F9H		; Interrupt-Priorittsregister
IRQ		EQU	0FAH		; Interrupt-Anmelderegister
RP		EQU	0FDH		; Registerpointer

;------------------------------------------------------------------------------
; AS-Funktionen
hi	function x,(x>>8)&255
lo	function x, x&255


